<?php
/**
 * BCS附件上传
 * 
 * @package BCS 
 * @author 孤独小坏
 * @version 1.0.0
 * @link http://www.7xcode.com
 */
class BCS_Plugin implements Typecho_Plugin_Interface
{
    /**
     * 激活插件方法,如果激活失败,直接抛出异常
     * 
     * @access public
     * @return void
     * @throws Typecho_Plugin_Exception
     */
    public static function activate()
    {
        Typecho_Plugin::factory('Widget_Upload')->uploadHandle = array('BCS_Plugin', 'uploadHandle');
        Typecho_Plugin::factory('Widget_Upload')->modifyHandle = array('BCS_Plugin', 'modifyHandle');
        Typecho_Plugin::factory('Widget_Upload')->deleteHandle = array('BCS_Plugin', 'deleteHandle');
        Typecho_Plugin::factory('Widget_Upload')->attachmentHandle = array('BCS_Plugin', 'attachmentHandle');
        return _t('插件已经激活，需先配置插件的信息！');
    }
    
    public static function deactivate(){}
    
    public static function config(Typecho_Widget_Helper_Form $form)
    {
        $bucket = new Typecho_Widget_Helper_Form_Element_Text('bucket', null, null, _t('空间名称：'));
        $form->addInput($bucket->addRule('required', _t('“空间名称”不能为空！')));

        $accesskey = new Typecho_Widget_Helper_Form_Element_Text('accesskey', null, null, _t('AccessKey：'));
        $form->addInput($accesskey->addRule('required', _t('AccessKey 不能为空！')));

        $sercetkey = new Typecho_Widget_Helper_Form_Element_Text('sercetkey', null, null, _t('SecretKey：'));
        $form->addInput($sercetkey->addRule('required', _t('SecretKey 不能为空！')));
        
        $savepath = new Typecho_Widget_Helper_Form_Element_Text('savepath', null, '{year}{month}{day}/', _t('保存路径格式：'), _t('附件保存路径的格式，默认为 Typecho 的 {year}/{month}/ 格式，注意<strong style="color:#C33;">前面不要加 / </strong>！<br />可选参数：{year} 年份、{month} 月份、{day} 日期'));
        $form->addInput($savepath->addRule('required', _t('请填写保存路径格式！')));
    }

    public static function personalConfig(Typecho_Widget_Helper_Form $form){}
    
    public static function dwDeleteFile($filepath)
    {
        self::initSDK();
        $options = Typecho_Widget::widget('Widget_Options');
        $bucket  = $options->plugin('BCS')->bucket;
        $dwak    = $options->plugin('BCS')->accesskey;
        $dwsk    = $options->plugin('BCS')->sercetkey;
        $baidu_bcs = new BaiduBCS($dwak, $dwsk, 'bcs.duapp.com');
        $response = $baidu_bcs->delete_object($bucket, $filepath);
        if ($response->isOK())
        {
          return _t('文件删除成功');
        }
        else return _t('文件删除失败');
    }
    
    public static function uploadHandle($file)
    {
        if (empty($file['name'])) return false;
        $part = explode('.', $file['name']);
        $ext = (($length = count($part)) > 1) ? strtolower($part[$length-1]) : '';
        if (!Widget_Upload::checkFileType($ext)) return false;
        $options = Typecho_Widget::widget('Widget_Options');
        $date = new Typecho_Date($options->gmtTime);
        $path = $options->plugin('BCS')->savepath;
        $savepath = preg_replace(array('/\{year\}/', '/\{month\}/', '/\{day\}/'), array($date->year, $date->month, $date->day), $path);
        $savename = '/' . $savepath . $file['name'];
        $savename = rawurldecode($savename);
        $savename = str_replace(" ", "_", $savename);
        $filename = $file['tmp_name'];
        if (!isset($filename)) return false;
        self::initSDK();
        $bucket = $options->plugin('BCS')->bucket;
        $dwak = $options->plugin('BCS')->accesskey;
        $dwsk = $options->plugin('BCS')->sercetkey;
        $baidu_bcs = new BaiduBCS($dwak, $dwsk, 'bcs.duapp.com');
        $baidu_bcs->delete_object($bucket, $savename);
        $opt = array("acl" => "public-read");
        $response = $baidu_bcs->create_object($bucket, $savename, $filename, $opt);
        $acl = array (
              'statements' => array (
                  '0' => array (
                      'user' => array (
                          "*" ), 
                      'resource' => array (
                          $bucket . $savename), 
                      'action' => array (
                          BaiduBCS::BCS_SDK_ACL_ACTION_GET_OBJECT
                           ), 
                      'effect' => BaiduBCS::BCS_SDK_ACL_EFFECT_ALLOW,
                      'referer' => $referer
                            ) ) );
        $baidu_bcs->set_object_acl($bucket, $savename, $acl);
        if ($response->isOK())
        {
            return array
            (
                'name'  =>  $file['name'],
                'path'  =>  $savename,
                'size'  =>  $file['size'],
                'type'  =>  $ext,
                'mime'  =>  Typecho_Common::mimeContentType($savename)
            );
        }
        else return -1;
    }
    
    public static function modifyHandle($content, $file)
    {
        return self::dwUploadFile($file, $content);
    }
    
    public static function deleteHandle(array $content)
    {
       return self::dwDeleteFile($content['attachment']->path);
    }
    
    public static function attachmentHandle(array $content)
    {
        $options = Typecho_Widget::widget('Widget_Options');
        $bucket = $options->plugin('BCS')->bucket;
        return Typecho_Common::url($content['attachment']->path, 'http://bcs.duapp.com/'. $bucket);
    }
    
    public static function initSDK()
    {
      require_once 'SDK/bcs.class.php';
    }
}
